==> snipe-it-8.0.1.zip: snipe-it-8.0.1/resources/lang/so-SO/admin/custom_fields/general.php <==
<?php

return [
    'custom_fields'		        => 'Goobaha gaarka ah',
    'manage'                    => 'Maamul',
    'field'		                => 'Garoonka',
    'about_fieldsets_title'		=> 'Ku saabsan Fieldsets',
    'about_fieldsets_text'		=> 'Fieldsets waxay kuu oggolaanayaan inaad abuurto kooxo garoomo gaar ah kuwaas oo inta badan dib loogu isticmaalo noocyada moodooyinka hantida gaarka ah.',
    'custom_format'             => 'Qaabka Regex ee gaarka ah...',
    'encrypt_field'      	        => 'Siri qiimaha goobtan kaydka xogta',
    'encrypt_field_help'      => 'DIGNIIN: Siraynta goobta ayaa ka dhigaysa mid aan la baari karin.',
    'encrypted'      	        => 'Qarsoon',
    'fieldset'      	        => 'Goobta garoonka',
    'qty_fields'      	      => 'Goobaha Qty',
    'fieldsets'      	        => 'Goobaha garoonka',
    'fieldset_name'           => 'Magaca Goobta',
    'field_name'              => 'Magaca Goobta',
    'field_values'            => 'Qiimaha Goobta',
    'field_values_help'       => 'Ku dar xulashooyin la dooran karo, sadar kasta hal xulasho. waa la iska indha tiri doonaa sadarada faaruqa ah marka laga reebo sadarka koowaad.',
    'field_element'           => 'Qaybta Foomka',
    'field_element_short'     => 'Cunsurka',
    'field_format'            => 'Qaabka',
    'field_custom_format'     => 'Qaabka Regex Custom',
    'field_custom_format_help'     => 'Goobtani waxay kuu ogolaanaysaa inaad isticmaasho tacbiir cadi ah si aad u hubsato sax ahaanshaha. waa inuu ka billowdaaa "regex:" - tusaale ahaan, si loo xaqiijiyo in qiimaha goobta gaarka ahi ku jirto nambar  saxan oo IMEI (15 lambar), waxaad isticmaali doontaa <code>regex:/^[0-9]{15}$ /</code>.',
    'required'   		          => 'Loo baahan yahay',
    'req'   		              => 'Req.',
    'used_by_models'   		    => 'Waxaa Isticmaala Moodooyinka',
    'order'   		            => 'Dalbo',
    'create_fieldset'         => 'Goob Cusub',
    'update_fieldset'         => 'Cusbooneysii Fieldset',
    'fieldset_does_not_exist'   => 'Fieldset :id ma jiro',
    'fieldset_updated'         => 'Goobta goobta waa la cusboonaysiiyay',
    'create_fieldset_title' => 'Samee goob cusub',
    'create_field'            => 'Garoonka Cusub ee Custom',
    'create_field_title' => 'Samee goob cusub oo caado ah',
    'value_encrypted'      	        => 'Qiimaha goobtan waxa lagu sir ah kaydka xogta. Kaliya isticmaalayaasha maamulka ayaa awoodi doona inay arkaan qiimaha la furay',
    'show_in_email'     => 'Ku dar qiimaha goobtan fariimaha hubinta ee loo soo diray isticmaalaha? Goobaha sirta ah laguma dari karo iimaylada',
    'show_in_email_short' => 'Ku dar emails',
    'help_text' => 'Qoraalka Caawinta',
    'help_text_description' => 'Kani waa qoraal ikhtiyaari ah oo ka soo bixi doona hoosta qaybaha foomka marka la tafatiro hantida si loo bixiyo macnaha guud ee goobta.',
    'about_custom_fields_title' => 'Ku saabsan Goobaha Gaarka ah',
    'about_custom_fields_text' => 'Goobaha gaarka ah waxay kuu oggolaanayaan inaad ku darto sifooyin aan sabab lahayn hantida.',
    'add_field_to_fieldset' => 'Kudar Goobta Goobta',
    'make_optional' => 'Loo baahan yahay - dhagsii si aad ikhtiyaar u sameyso',
    'make_required' => 'Ikhtiyaar-guji si loo baahdo',
    'reorder' => 'Dib u dalbo',
    'db_field' => 'Goobta DB',
    'db_convert_warning' => 'DIGNIIN. Goobtani waxay ku dhex jirtaa shaxda qaaska ah ee beeraha sida <code>:db_column</code> laakiin waa inay noqotaa <kood>:expected</code>.',
    'is_unique' => 'Qiimahani waa inuu noqdaa mid u gaar ah dhammaan hantida',
    'unique' => 'Gaar ah',
    'display_in_user_view' => 'U oggolow isticmaale la hubiyay inuu ku arko qiimayaashan boggooda Hantida la qoondeeyay',
    'display_in_user_view_table' => 'U Muuqda Isticmaalaha',
    'auto_add_to_fieldsets' => 'Si toos ah ugu dar tan goob kasta oo cusub',
    'add_to_preexisting_fieldsets' => 'Ku dar goob kasta oo jira',
    'show_in_listview' => 'U muuji liiska aragtiyaha sida caadiga ah. Isticmaalayaasha idman ayaa wali awood u yeelan doona inay muujiyaan/qariyaan iyagoo isticmaalaya xulashada tiirka',
    'show_in_listview_short' => 'Ku muuji liisaska',
    'show_in_requestable_list_short' => 'Ku muuji liiska hantida la codsan karo',
    'show_in_requestable_list' => 'Muuji qiimaha liiska hantida la codsan karo. Goobaha sirta ah lama tusi doono',
    'encrypted_options' => 'Goobtan waa la sir sir ah, marka qaar ka mid ah xulashooyinka bandhiga lama heli doono.',
    'display_checkin' => 'Display in checkin forms',
    'display_checkout' => 'Display in checkout forms',

];

==> snipe-it-8.3.3.zip: snipe-it-8.3.3/resources/lang/so-SO/admin/custom_fields/general.php <==
<?php

return [
    'custom_fields'		        => 'Goobaha gaarka ah',
    'manage'                    => 'Maamul',
    'field'		                => 'Garoonka',
    'about_fieldsets_title'		=> 'Ku saabsan Fieldsets',
    'about_fieldsets_text'		=> 'Fieldsets waxay kuu oggolaanayaan inaad abuurto kooxo garoomo gaar ah kuwaas oo inta badan dib loogu isticmaalo noocyada moodooyinka hantida gaarka ah.',
    'custom_format'             => 'Qaabka Regex ee gaarka ah...',
    'encrypt_field'      	        => 'Siri qiimaha goobtan kaydka xogta',
    'encrypt_field_help'      => 'DIGNIIN: Siraynta goobta ayaa ka dhigaysa mid aan la baari karin.',
    'encrypted'      	        => 'Qarsoon',
    'fieldset'      	        => 'Goobta garoonka',
    'qty_fields'      	      => 'Goobaha Qty',
    'fieldsets'      	        => 'Goobaha garoonka',
    'fieldset_name'           => 'Magaca Goobta',
    'field_name'              => 'Magaca Goobta',
    'field_values'            => 'Qiimaha Goobta',
    'field_values_help'       => 'Ku dar xulashooyin la dooran karo, sadar kasta hal xulasho. waa la iska indha tiri doonaa sadarada faaruqa ah marka laga reebo sadarka koowaad.',
    'field_element'           => 'Qaybta Foomka',
    'field_element_short'     => 'Cunsurka',
    'field_format'            => 'Qaabka',
    'field_custom_format'     => 'Qaabka Regex Custom',
    'field_custom_format_help'     => 'Goobtani waxay kuu ogolaanaysaa inaad isticmaasho tacbiir cadi ah si aad u hubsato sax ahaanshaha. waa inuu ka billowdaaa "regex:" - tusaale ahaan, si loo xaqiijiyo in qiimaha goobta gaarka ahi ku jirto nambar  saxan oo IMEI (15 lambar), waxaad isticmaali doontaa <code>regex:/^[0-9]{15}$ /</code>.',
    'required'   		          => 'Loo baahan yahay',
    'req'   		              => 'Req.',
    'used_by_models'   		    => 'Waxaa Isticmaala Moodooyinka',
    'order'   		            => 'Dalbo',
    'create_fieldset'         => 'Goob Cusub',
    'update_fieldset'         => 'Cusbooneysii Fieldset',
    'fieldset_does_not_exist'   => 'Fieldset :id ma jiro',
    'fieldset_updated'         => 'Goobta goobta waa la cusboonaysiiyay',
    'create_fieldset_title' => 'Samee goob cusub',
    'create_field'            => 'Garoonka Cusub ee Custom',
    'create_field_title' => 'Samee goob cusub oo caado ah',
    'value_encrypted'      	        => 'The value of this field is encrypted in the database. Only users with permission to view encrypted custom fields will be able to view the decrypted value',
    'show_in_email'     => 'Ku dar qiimaha goobtan fariimaha hubinta ee loo soo diray isticmaalaha? Goobaha sirta ah laguma dari karo iimaylada',
    'show_in_email_short' => 'Ku dar emails',
    'help_text' => 'Qoraalka Caawinta',
    'help_text_description' => 'Kani waa qoraal ikhtiyaari ah oo ka soo bixi doona hoosta qaybaha foomka marka la tafatiro hantida si loo bixiyo macnaha guud ee goobta.',
    'about_custom_fields_title' => 'Ku saabsan Goobaha Gaarka ah',
    'about_custom_fields_text' => 'Goobaha gaarka ah waxay kuu oggolaanayaan inaad ku darto sifooyin aan sabab lahayn hantida.',
    'add_field_to_fieldset' => 'Kudar Goobta Goobta',
    'make_optional' => 'Loo baahan yahay - dhagsii si aad ikhtiyaar u sameyso',
    'make_required' => 'Ikhtiyaar-guji si loo baahdo',
    'reorder' => 'Dib u dalbo',
    'db_field' => 'Goobta DB',
    'db_convert_warning' => 'DIGNIIN. Goobtani waxay ku dhex jirtaa shaxda qaaska ah ee beeraha sida <code>:db_column</code> laakiin waa inay noqotaa <kood>:expected</code>.',
    'is_unique' => 'Qiimahani waa inuu noqdaa mid u gaar ah dhammaan hantida',
    'unique' => 'Gaar ah',
    'display_in_user_view' => 'U oggolow isticmaale la hubiyay inuu ku arko qiimayaashan boggooda Hantida la qoondeeyay',
    'display_in_user_view_table' => 'U Muuqda Isticmaalaha',
    'auto_add_to_fieldsets' => 'Si toos ah ugu dar tan goob kasta oo cusub',
    'add_to_preexisting_fieldsets' => 'Ku dar goob kasta oo jira',
    'show_in_listview' => 'U muuji liiska aragtiyaha sida caadiga ah. Isticmaalayaasha idman ayaa wali awood u yeelan doona inay muujiyaan/qariyaan iyagoo isticmaalaya xulashada tiirka',
    'show_in_listview_short' => 'Ku muuji liisaska',
    'show_in_requestable_list_short' => 'Ku muuji liiska hantida la codsan karo',
    'show_in_requestable_list' => 'Muuji qiimaha liiska hantida la codsan karo. Goobaha sirta ah lama tusi doono',
    'encrypted_options' => 'Goobtan waa la sir sir ah, marka qaar ka mid ah xulashooyinka bandhiga lama heli doono.',
    'display_checkin' => 'Display in checkin forms',
    'display_checkout' => 'Display in checkout forms',
    'display_audit' => 'Display in audit forms',
    'types' => [
        'text' => 'Text Box',
        'listbox' => 'List Box',
        'textarea' => 'Textarea (multi-line)',
        'checkbox' => 'Checkbox',
        'radio' => 'Radio Buttons',
    ],
];
